@@ -17,33 +17,13 @@
 **
 ** You should have received a copy of the GNU General Public License
 ** along with this program in a file called COPYING; if not, write to
-** the Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
-** MA 02111-1307, USA.
+** the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+** MA 02110-1301, USA.
 */
 
 /*
 ** Bug reports and questions can be sent to kde-devel@kde.org
 */
-#include <stdlib.h>
-#include <unistd.h>
-#include <time.h>
-
-#include <kdebug.h>
-
-#include <kpopupmenu.h>
-#include <qtimer.h>
-#include <qcursor.h>
-#include <qvaluelist.h>
-
-#include <klocale.h>
-#include <kmessagebox.h>
-#include <kstartupinfo.h>
-#include <kwin.h>
-#include <kwinmodule.h>
-#include <kstandarddirs.h>
-#include <khelpmenu.h>
-#include <kiconloader.h>
-
 #include "amor.h"
 #include "amor.moc"
 #include "amorpm.h"
@@ -51,9 +31,32 @@
 #include "amorwidget.h"
 #include "amordialog.h"
 #include "version.h"
-#include <X11/Xlib.h>
-#include <kdebug.h>
+#include "amoradaptor.h"
 
+#include <stdlib.h>
+#include <unistd.h>
+#include <time.h>
+
+#include <QtDBus/QtDBus>
+#include <QtCore/QTimer>
+#include <QtGui/QCursor>
+
+#include <kmenu.h>
+#include <kapplication.h>
+#include <kdebug.h>
+#include <klocale.h>
+#include <kmessagebox.h>
+#include <kstartupinfo.h>
+#include <kwindowsystem.h>
+#include <kstandarddirs.h>
+#include <khelpmenu.h>
+#include <kiconloader.h>
+#include <krandom.h>
+
+#if defined Q_WS_X11
+#include <X11/Xlib.h>
+#include <QtGui/QX11Info>
+#endif
 // #define DEBUG_AMOR
 
 #define SLEEP_TIMEOUT   180     // Animation sleeps after SLEEP_TIMEOUT seconds
@@ -78,14 +81,14 @@
 // Constructor
 //
 
-QueueItem::QueueItem(itemType ty, QString te, int ti)
+QueueItem::QueueItem(itemType ty, const QString &te, int ti)
 {
-    // if the time field was not given, calculate one based on the type 
+    // if the time field was not given, calculate one based on the type
     // and length of the item
     int effectiveLength = 0, nesting = 0;
 
-    // discard html code from the lenght count
-    for (unsigned int i = 0; i < te.length(); i++)
+    // discard html code from the length count
+    for (int i = 0; i < te.length(); i++)
     {
 	if (te[i] == '<')	nesting++;
 	else if (te[i] == '>')	nesting--;
@@ -94,7 +97,7 @@ QueueItem::QueueItem(itemType ty, QString te, int ti)
     if (nesting) // malformed html
     {
 #ifdef DEBUG_AMOR
-	kdDebug(10000) << "QueueItem::QueueItem(): Malformed HTML!" << endl;
+	kDebug(10000) << "QueueItem::QueueItem(): Malformed HTML!";
 #endif
 	effectiveLength = te.length();
     }
@@ -120,8 +123,10 @@ QueueItem::QueueItem(itemType ty, QString te, int ti)
 // AMOR
 // Constructor
 //
-Amor::Amor() : DCOPObject( "AmorIface" ), QObject()
+Amor::Amor() : QObject()
 {
+    new AmorAdaptor(this);
+    QDBusConnection::sessionBus().registerObject("/Amor", this);
     mAmor = 0;
     mBubble = 0;
     mForceHideAmorWidget = false;
@@ -135,7 +140,7 @@ Amor::Amor() : DCOPObject( "AmorIface" ), QObject()
         mPosition    = mCurrAnim->hotspot().x();
         mState       = Normal;
 
-        mWin = new KWinModule;
+        mWin = KWindowSystem::self();
         connect(mWin, SIGNAL(activeWindowChanged(WId)),
                 this, SLOT(slotWindowActivate(WId)));
         connect(mWin, SIGNAL(windowRemoved(WId)),
@@ -159,7 +164,7 @@ Amor::Amor() : DCOPObject( "AmorIface" ), QObject()
 
         mStackTimer = new QTimer(this);
         connect(mStackTimer, SIGNAL(timeout()), SLOT(restack()));
-    
+
 	mBubbleTimer = new QTimer(this);
 	connect(mBubbleTimer, SIGNAL(timeout()), SLOT(slotBubbleTimeout()));
 
@@ -173,25 +178,26 @@ Amor::Amor() : DCOPObject( "AmorIface" ), QObject()
         {
             mNextTarget = mWin->activeWindow();
             selectAnimation(Focus);
-            mTimer->start(0, true);
+            mTimer->setSingleShot(true);
+            mTimer->start(0);
         }
-	if (!connectDCOPSignal(0,0, "KDE_stop_screensaver()", "screenSaverStopped()",false))
-		kdDebug(10000) << "Could not attach signal...KDE_stop_screensaver()" << endl;
+        if ( !QDBusConnection::sessionBus().connect(QString(), QString(), "org.kde.amor",
+                    "KDE_stop_screensaver", this, SLOT( screenSaverStopped()) ) )
+		kDebug(10000) << "Could not attach signal...KDE_stop_screensaver()";
 	else
-		kdDebug(10000) << "attached dcop signals..." << endl;
+		kDebug(10000) << "attached dbus signals...";
 
-	if (!connectDCOPSignal(0,0, "KDE_start_screensaver()", "screenSaverStarted()",false))
-		kdDebug(10000) << "Could not attach signal...KDE_start_screensaver()" << endl;
+         if ( !QDBusConnection::sessionBus().connect(QString(), QString(), "org.kde.amor", "KDE_start_screensaver", this, SLOT( screenSaverStarted()) ) )
+		kDebug(10000) << "Could not attach signal...KDE_start_screensaver()";
 	else
-		kdDebug(10000) << "attached dcop signals..." << endl;
+		kDebug(10000) << "attached dbus signals...";
 
-	mTipsQueue.setAutoDelete(true);
 
 	KStartupInfo::appStarted();
     }
     else
     {
-        kapp->quit();
+        qApp->quit();
     }
 }
 
@@ -201,7 +207,8 @@ Amor::Amor() : DCOPObject( "AmorIface" ), QObject()
 //
 Amor::~Amor()
 {
-    delete mWin;
+	qDeleteAll(mTipsQueue);
+	mTipsQueue.clear();
     delete mAmor;
     delete mBubble;
 }
@@ -209,19 +216,20 @@ Amor::~Amor()
 void Amor::screenSaverStopped()
 {
 #ifdef DEBUG_AMOR
-    kdDebug(10000)<<"void Amor::screenSaverStopped() \n";
+    kDebug(10000)<<"void Amor::screenSaverStopped() \n";
 #endif
 
     mAmor->show();
     mForceHideAmorWidget = false;
 
-    mTimer->start(0, true);
+    mTimer->setSingleShot(true);
+    mTimer->start(0);
 }
 
 void Amor::screenSaverStarted()
 {
 #ifdef DEBUG_AMOR
-    kdDebug(10000)<<"void Amor::screenSaverStarted() \n";
+    kDebug(10000)<<"void Amor::screenSaverStarted() \n";
 #endif
 
     mAmor->hide();
@@ -234,7 +242,7 @@ void Amor::screenSaverStarted()
 
 //---------------------------------------------------------------------------
 //
-void Amor::showTip( QString tip )
+void Amor::showTip( const QString &tip )
 {
     if (mTipsQueue.count() < 5 && !mForceHideAmorWidget) // start dropping tips if the queue is too long
         mTipsQueue.enqueue(new QueueItem(QueueItem::Tip, tip));
@@ -242,17 +250,18 @@ void Amor::showTip( QString tip )
     if (mState == Sleeping)
     {
 	selectAnimation(Waking);	// Set waking immediatedly
-	mTimer->start(0, true);
+    mTimer->setSingleShot(true);
+	mTimer->start(0);
     }
 }
 
 
-void Amor::showMessage( QString message )
+void Amor::showMessage( const QString &message )
 {
     showMessage(message, -1);
 }
 
-void Amor::showMessage( QString message , int msec )
+void Amor::showMessage( const QString &message , int msec )
 {
     // FIXME: What should be done about messages and tips while the screensaver is on?
     if (mForceHideAmorWidget) return; // do not show messages sent while in the screensaver
@@ -262,7 +271,8 @@ void Amor::showMessage( QString message , int msec )
     if (mState == Sleeping)
     {
 	selectAnimation(Waking);	// Set waking immediatedly
-	mTimer->start(0, true);
+    mTimer->setSingleShot(true);
+	mTimer->start(0);
     }
 }
 
@@ -288,10 +298,11 @@ void Amor::reset()
     mPosition   = mCurrAnim->hotspot().x();
     mState      = Normal;
 
-    mAmor->resize(mTheme.maximumSize()); 
+    mAmor->resize(mTheme.maximumSize());
     mCurrAnim->reset();
 
-    mTimer->start(0, true);
+    mTimer->setSingleShot(true);
+    mTimer->start(0);
 }
 
 //---------------------------------------------------------------------------
@@ -309,17 +320,20 @@ bool Amor::readConfig()
     }
 
     // Select a random theme if user requested it
-	if (mConfig.mRandomTheme)
-	{
-		QStringList files(KGlobal::dirs()->findAllResources("appdata", "*rc"));
-		int randomTheme = kapp->random() % files.count();
-		mConfig.mTheme = (QString)*files.at(randomTheme);
-	}
-	
+    if (mConfig.mRandomTheme)
+    {
+        QStringList files;
+
+        // Store relative paths into files to avoid storing absolute pathnames.
+        KGlobal::dirs()->findAllResources("appdata", "*rc", KStandardDirs::NoSearchOptions, files);
+        int randomTheme = KRandom::random() % files.count();
+        mConfig.mTheme = files.at(randomTheme);
+    }
+
     // read selected theme
     if (!mTheme.setTheme(mConfig.mTheme))
     {
-        KMessageBox::error(0, i18n("Error reading theme: ") + mConfig.mTheme);
+        KMessageBox::error(0, i18nc("@info:status", "Error reading theme: ") + mConfig.mTheme);
         return false;
     }
 
@@ -333,7 +347,7 @@ bool Amor::readConfig()
 	{
 	    if (mTheme.readGroup(groups[i]) == false)
 	    {
-		KMessageBox::error(0, i18n("Error reading group: ") + groups[i]);
+		KMessageBox::error(0, i18nc("@info:status", "Error reading group: ") + groups[i]);
 		return false;
 	    }
 	}
@@ -342,7 +356,7 @@ bool Amor::readConfig()
     {
 	if ( mTheme.readGroup( ANIM_BASE ) == false )
 	{
-	    KMessageBox::error(0, i18n("Error reading group: ") + ANIM_BASE);
+	    KMessageBox::error(0, i18nc("@info:status", "Error reading group: ") + ANIM_BASE);
 	    return false;
 	}
     }
@@ -362,7 +376,7 @@ void Amor::showBubble()
     if (!mTipsQueue.isEmpty())
     {
 #ifdef DEBUG_AMOR
-    kdDebug(10000) << "Amor::showBubble(): Displaying tips bubble." << endl;
+    kDebug(10000) << "Amor::showBubble(): Displaying tips bubble.";
 #endif
 
         if (!mBubble)
@@ -375,7 +389,8 @@ void Amor::showBubble()
         mBubble->setMessage(mTipsQueue.head()->text());
 
 //	mBubbleTimer->start(mTipsQueue.head()->time(), true);
-	mBubbleTimer->start(BUBBLE_TIME_STEP, true);
+    mBubbleTimer->setSingleShot(true);
+	mBubbleTimer->start(BUBBLE_TIME_STEP);
     }
 }
 
@@ -388,21 +403,21 @@ void Amor::hideBubble(bool forceDequeue)
     if (mBubble)
     {
 #ifdef DEBUG_AMOR
-    kdDebug(10000) << "Amor::hideBubble(): Hiding tips bubble" << endl;
+    kDebug(10000) << "Amor::hideBubble(): Hiding tips bubble";
 #endif
 
         // GP: stop mBubbleTimer to avoid deleting the first element, just in case we are changing windows
 	// or something before the tip was shown long enough
         mBubbleTimer->stop();
 
-	// GP: the first message on the queue should be taken off for a 
-	// number of reasons: a) forceDequeue == true, only when called 
-	// from slotBubbleTimeout; b) the bubble is not visible ; c) 
-	// the bubble is visible, but there's Tip being displayed. The 
-	// latter is to keep backwards compatibility and because 
-	// carrying around a tip bubble when switching windows quickly is really 
+	// GP: the first message on the queue should be taken off for a
+	// number of reasons: a) forceDequeue == true, only when called
+	// from slotBubbleTimeout; b) the bubble is not visible ; c)
+	// the bubble is visible, but there's Tip being displayed. The
+	// latter is to keep backwards compatibility and because
+	// carrying around a tip bubble when switching windows quickly is really
 	// annoyying
-	if (forceDequeue || !mBubble->isVisible() || 
+	if (forceDequeue || !mBubble->isVisible() ||
 	    (mTipsQueue.head()->type() == QueueItem::Tip)) /* there's always an item in the queue here */
 	    mTipsQueue.dequeue();
 
@@ -432,9 +447,9 @@ void Amor::selectAnimation(State state)
             mTargetWin = mNextTarget;
             if (mTargetWin != None)
             {
-                mTargetRect = KWin::windowInfo(mTargetWin).frameGeometry();
+                mTargetRect = KWindowSystem::windowInfo(mTargetWin, NET::WMFrameExtents).frameGeometry();
 
-		// if the animation falls outside of the working area, 
+		// if the animation falls outside of the working area,
 		// then relocate it so that is inside the desktop again
 		QRect desktopArea = mWin->workArea();
 		mInDesktopBottom = false;
@@ -443,11 +458,11 @@ void Amor::selectAnimation(State state)
 		    desktopArea.y())
 		{
 		    // relocate the animation at the bottom of the screen
-		    mTargetRect = QRect(desktopArea.x(), 
+		    mTargetRect = QRect(desktopArea.x(),
 				  desktopArea.y() + desktopArea.height(),
 				  desktopArea.width(), 0);
 
-		    // we'll relocate the animation in the desktop 
+		    // we'll relocate the animation in the desktop
 		    // frame, so do not add the offset to its vertical position
 		    mInDesktopBottom = true;
 		}
@@ -470,7 +485,7 @@ void Amor::selectAnimation(State state)
 		        if (mTargetRect.width() == mCurrAnim->frame()->width())
 			    mPosition = mCurrAnim->hotspot().x();
 			else
-			    mPosition = ( kapp->random() %
+			    mPosition = ( KRandom::random() %
 					  (mTargetRect.width() - mCurrAnim->frame()->width()) )
 					 + mCurrAnim->hotspot().x();
 		    }
@@ -487,7 +502,7 @@ void Amor::selectAnimation(State state)
                 mTimer->stop();
             }
             mAmor->hide();
-	    
+
             restack();
             mState = Normal;
             break;
@@ -555,9 +570,9 @@ void Amor::restack()
     }
 
 #ifdef DEBUG_AMOR
-    kdDebug(10000) << "restacking" << endl;
+    kDebug(10000) << "restacking";
 #endif
-
+#if defined Q_WS_X11
     Window sibling = mTargetWin;
     Window dw, parent = None, *wins;
 
@@ -566,7 +581,7 @@ void Amor::restack()
 
         // We must use the target window's parent as our sibling.
         // Is there a faster way to get parent window than XQueryTree?
-        if (XQueryTree(qt_xdisplay(), sibling, &dw, &parent, &wins, &nwins))
+        if (XQueryTree(QX11Info::display(), sibling, &dw, &parent, &wins, &nwins))
         {
             if (nwins)
             {
@@ -583,8 +598,9 @@ void Amor::restack()
     XWindowChanges values;
     values.sibling = sibling;
     values.stack_mode = Above;
-    XConfigureWindow(qt_xdisplay(), mAmor->winId(), CWSibling | CWStackMode,
+    XConfigureWindow(QX11Info::display(), mAmor->winId(), CWSibling | CWStackMode,
                      &values);
+#endif
 }
 
 //---------------------------------------------------------------------------
@@ -603,21 +619,29 @@ void Amor::slotMouseClicked(const QPoint &pos)
 
     if (!mMenu)
     {
-        KHelpMenu* help = new KHelpMenu(0, KGlobal::instance()->aboutData(), false);
-        KPopupMenu* helpMnu = help->menu();
-        mMenu = new KPopupMenu();
-        mMenu->insertTitle("Amor"); // I really don't want this i18n'ed
-        mMenu->insertItem(SmallIcon("configure"), i18n("&Configure..."), this, SLOT(slotConfigure()));
-        mMenu->insertSeparator();
-        mMenu->insertItem(SmallIcon("help"), i18n("&Help"), helpMnu);
-        mMenu->insertItem(SmallIcon("exit"), i18n("&Quit"), kapp, SLOT(quit()));
+        KHelpMenu* help = new KHelpMenu(0, KGlobal::mainComponent().aboutData(), false);
+        KMenu* helpMenu = help->menu();
+#ifdef __GNUC__
+#warning the following is kinda dirty and should be done by KHelpMenu::menu() I think. (hermier)
+#endif
+        helpMenu->setIcon(SmallIcon("help-contents"));
+        helpMenu->setTitle(i18nc("@action:inmenu Amor", "&Help"));
+
+        mMenu = new KMenu(0);
+        mMenu->addTitle("Amor"); // I really don't want this i18n'ed
+        mMenu->addAction(SmallIcon("configure"), i18nc("@action:inmenu Amor", "&Configure..."), this, SLOT(slotConfigure()));
+        mMenu->addSeparator();
+        mMenu->addMenu(helpMenu);
+        mMenu->addAction(SmallIcon("application-exit"), i18nc("@action:inmenu Amor", "&Quit"), kapp, SLOT(quit()));
     }
 
     mMenu->exec(pos);
 
     if (restartTimer)
     {
-        mTimer->start(1000, true);
+
+        mTimer->setSingleShot(true);
+        mTimer->start(1000);
     }
 }
 
@@ -673,22 +697,25 @@ void Amor::slotTimeout()
 
     if (mCurrAnim == mBaseAnim && mCurrAnim->validFrame())
     {
-	// GP: Application tips/messages can be shown in any frame number; amor tips are 
+	// GP: Application tips/messages can be shown in any frame number; amor tips are
 	// only displayed on the first frame of mBaseAnim (the old way of doing this).
 	if ( !mTipsQueue.isEmpty() && !mBubble &&  mConfig.mAppTips)
 	    showBubble();
-	else if (kapp->random()%TIP_FREQUENCY == 1 && mConfig.mTips && !mBubble && !mCurrAnim->frameNum())
+	else if (KRandom::random()%TIP_FREQUENCY == 1 && mConfig.mTips && !mBubble && !mCurrAnim->frameNum())
         {
-	    mTipsQueue.enqueue(new QueueItem(QueueItem::Tip, mTips.tip())); 
+	    mTipsQueue.enqueue(new QueueItem(QueueItem::Tip, mTips.tip()));
 	    showBubble();
         }
     }
 
-    if (mTheme.isStatic())
-	mTimer->start((mState == Normal) || (mState == Sleeping) ? 1000 : 100, true);
-    else
-	mTimer->start(mCurrAnim->delay(), true);
-
+    if (mTheme.isStatic()) {
+	    mTimer->setSingleShot(true);
+        mTimer->start((mState == Normal) || (mState == Sleeping) ? 1000 : 100);
+    }
+    else {
+        mTimer->setSingleShot(true);
+	    mTimer->start(mCurrAnim->delay());
+    }
     if (!mCurrAnim->next())
     {
 	if ( mBubble )
@@ -745,13 +772,13 @@ void Amor::slotOffsetChanged(int off)
 //
 void Amor::slotAbout()
 {
-    QString about = i18n("Amor Version %1\n\n").arg(AMOR_VERSION) +
-                i18n("Amusing Misuse Of Resources\n\n") +
-                i18n("Copyright (c) 1999 Martin R. Jones <mjones@kde.org>\n\n") +
-		i18n("Original Author: Martin R. Jones <mjones@kde.org>\n") +
-		i18n("Current Maintainer: Gerardo Puga <gpuga@gioia.ing.unlp.edu.ar>\n" ) +
+    QString about = i18nc("@label:textbox", "Amor Version %1\n\n", QString::fromLatin1(AMOR_VERSION)) +
+                i18nc("@label:textbox", "Amusing Misuse Of Resources\n\n") +
+                i18nc("@label:textbox", "Copyright 1999 Martin R. Jones <email>mjones@kde.org</email>\n\n") +
+		i18nc("@label:textbox", "Original Author: Martin R. Jones <email>mjones@kde.org</email>\n") +
+		i18nc("@label:textbox", "Current Maintainer: Gerardo Puga <email>gpuga@gioia.ing.unlp.edu.ar</email>\n" ) +
                 "\nhttp://www.powerup.com.au/~mjones/amor/";
-    KMessageBox::about(0, about, i18n("About Amor"));
+    KMessageBox::about(0, about, i18nc("@label:textbox", "About Amor"));
 }
 
 //---------------------------------------------------------------------------
@@ -790,7 +817,7 @@ void Amor::slotWidgetDragged( const QPoint &delta, bool release )
 void Amor::slotWindowActivate(WId win)
 {
 #ifdef DEBUG_AMOR
-    kdDebug(10000) << "Window activated:" << win << endl;
+    kDebug(10000) << "Window activated:" << win;
 #endif
 
     mTimer->stop();
@@ -805,14 +832,16 @@ void Amor::slotWindowActivate(WId win)
     {
         // We are losing focus from the current window
         selectAnimation(Blur);
-        mTimer->start(0, true);
+        mTimer->setSingleShot(true);
+        mTimer->start(0);
     }
     else if (mNextTarget)
     {
         // We are setting focus to a new window
         if (mState != Focus )
 	    selectAnimation(Focus);
-	mTimer->start(0, true);
+        mTimer->setSingleShot(true);
+    	mTimer->start(0);
     }
     else
     {
@@ -829,7 +858,7 @@ void Amor::slotWindowActivate(WId win)
 void Amor::slotWindowRemove(WId win)
 {
 #ifdef DEBUG_AMOR
-    kdDebug(10000) << "Window removed" << endl;
+    kDebug(10000) << "Window removed";
 #endif
 
     if (win == mTargetWin)
@@ -839,7 +868,8 @@ void Amor::slotWindowRemove(WId win)
 
         selectAnimation(Destroy);
         mTimer->stop();
-        mTimer->start(0, true);
+        mTimer->setSingleShot(true);
+        mTimer->start(0);
     }
 }
 
@@ -850,7 +880,7 @@ void Amor::slotWindowRemove(WId win)
 void Amor::slotStackingChanged()
 {
 #ifdef DEBUG_AMOR
-    kdDebug(10000) << "Stacking changed" << endl;
+    kDebug(10000) << "Stacking changed";
 #endif
 
     // This is an active event that affects the target window
@@ -858,7 +888,8 @@ void Amor::slotStackingChanged()
 
     // We seem to get this signal before the window has been restacked,
     // so we just schedule a restack.
-    mStackTimer->start( 20, TRUE );
+    mStackTimer->setSingleShot(true);
+    mStackTimer->start( 20);
 }
 
 //---------------------------------------------------------------------------
@@ -876,45 +907,47 @@ void Amor::slotWindowChange(WId win, const unsigned long * properties)
     // This is an active event that affects the target window
     time(&mActiveTime);
 
-    KWin::Info info = KWin::info( mTargetWin );
+    NET::MappingState mappingState = KWindowSystem::windowInfo( mTargetWin, NET::WMFrameExtents ).mappingState();
 
-    if (info.isIconified() ||
-        info.mappingState == NET::Withdrawn)
+    if (mappingState == NET::Iconic ||
+        mappingState == NET::Withdrawn)
     {
 #ifdef DEBUG_AMOR
-        kdDebug(10000) << "Target window iconified" << endl;
+        kDebug(10000) << "Target window iconified";
 #endif
 
         // The target window has been iconified
         selectAnimation(Destroy);
         mTargetWin = None;
         mTimer->stop();
-        mTimer->start(0, true);
+        mTimer->setSingleShot(true);
+        mTimer->start(0);
 
 	return;
     }
-    
-    if (properties[0] & NET::WMGeometry) 
+
+    if (properties[0] & NET::WMGeometry)
     {
 #ifdef DEBUG_AMOR
-        kdDebug(10000) << "Target window moved or resized" << endl;
+        kDebug(10000) << "Target window moved or resized";
 #endif
 
-        QRect newTargetRect = KWin::windowInfo(mTargetWin).frameGeometry();
+        QRect newTargetRect = KWindowSystem::windowInfo(mTargetWin, NET::WMFrameExtents).frameGeometry();
 
-	// if the change in the window caused the animation to fall 
-	// out of the working area of the desktop, or if the animation 
+	// if the change in the window caused the animation to fall
+	// out of the working area of the desktop, or if the animation
 	// didn't fall in the working area before but it does now, then
-	//  refocus on the current window so that the animation is 
+	//  refocus on the current window so that the animation is
 	// relocated.
 	QRect desktopArea = mWin->workArea();
 
-	bool fitsInWorkArea = !(newTargetRect.y() - mCurrAnim->hotspot().y() + mConfig.mOffset < desktopArea.y()); 
+	bool fitsInWorkArea = !(newTargetRect.y() - mCurrAnim->hotspot().y() + mConfig.mOffset < desktopArea.y());
 	if ((!fitsInWorkArea && !mInDesktopBottom) || (fitsInWorkArea && mInDesktopBottom))
 	{
 	    mNextTarget = mTargetWin;
 	    selectAnimation(Blur);
-	    mTimer->start(0, true);
+        mTimer->setSingleShot(true);
+	    mTimer->start(0);
 
 	    return;
 	}
@@ -956,13 +989,13 @@ void Amor::slotWindowChange(WId win, const unsigned long * properties)
 //
 void Amor::slotDesktopChange(int desktop)
 {
-    // GP: signal currentDesktopChanged seems to be emitted even if you 
+    // GP: signal currentDesktopChanged seems to be emitted even if you
     // change to the very same desktop you are in.
     if (mWin->currentDesktop() == desktop)
 	return;
 
 #ifdef DEBUG_AMOR
-    kdDebug(10000) << "Desktop change" << endl;
+    kDebug(10000) << "Desktop change";
 #endif
 
     mNextTarget = None;
@@ -979,12 +1012,13 @@ void Amor::slotBubbleTimeout()
     // has the queue item been displayed for long enough?
     QueueItem *first = mTipsQueue.head();
 #ifdef DEBUG_AMOR
-    if (!first)	kdDebug(10000) << "Amor::slotBubbleTimeout(): empty queue!" << endl;
+    if (!first)	kDebug(10000) << "Amor::slotBubbleTimeout(): empty queue!";
 #endif
     if ((first->time() > BUBBLE_TIME_STEP) && (mBubble->isVisible()))
     {
     	first->setTime(first->time() - BUBBLE_TIME_STEP);
-	mBubbleTimer->start(BUBBLE_TIME_STEP, true);
+        mBubbleTimer->setSingleShot(true);
+	mBubbleTimer->start(BUBBLE_TIME_STEP);
 	return;
     }
 
@@ -992,10 +1026,11 @@ void Amor::slotBubbleTimeout()
     if (mBubble->mouseWithin())
     {
 	first->setTime(500);		// show this item for another 500ms
-	mBubbleTimer->start(BUBBLE_TIME_STEP, true);
-	return;	
+    mBubbleTimer->setSingleShot(true);
+	mBubbleTimer->start(BUBBLE_TIME_STEP);
+	return;
     }
-    
+
     // are there any other tips pending?
     if (mTipsQueue.count() > 1)
     {
