@@ -16,80 +16,83 @@
  *                                                                         *
  ***************************************************************************/
 
-#include <kaboutapplication.h>
-#include <kapplication.h>
+#include "kweather.h"
+#include "reportview.h"
+#include "dockwidget.h"
+#include "kweatheradaptor.h"
+#include "serviceinterface.h"
+
+#include <kaboutapplicationdialog.h>
 #include <kcmultidialog.h>
 #include <kdebug.h>
 #include <klocale.h>
 #include <kiconloader.h>
 #include <kmessagebox.h>
-#include <kpopupmenu.h>
+#include <kmenu.h>
 #include <kconfig.h>
 #include <ksettings/dialog.h>
 #include <ksettings/dispatcher.h>
-#include <dcopclient.h>
+#include <kaboutdata.h>
+#include <ktoolinvocation.h>
 
-#include <qfile.h>
-#include <qtimer.h>
-#include <qpalette.h>
-
-#include "kweather.h"
-#include "reportview.h"
-#include "dockwidget.h"
-#include "weatherservice_stub.h"
+#include <QtCore/QFile>
+#include <QtCore/QTimer>
+#include <QtGui/QMouseEvent>
+#include <QtCore/QTextStream>
+#include <QtGui/QResizeEvent>
 
 extern "C"
 {
-    KDE_EXPORT KPanelApplet* init(QWidget *parent, const QString& configFile)
+    KDE_EXPORT K3PanelApplet* init(QWidget *parent, const QString& configFile)
     {
-        KGlobal::locale()->insertCatalogue("kweather");
-        kweather *theApplet = new kweather(configFile, KPanelApplet::Normal,
-                0, parent, "kweather");
+        KGlobal::locale()->insertCatalog("kweather");
+        kweather *theApplet = new kweather(configFile, K3PanelApplet::Normal, 0, parent);
         return theApplet;
     }
 }
 
-kweather::kweather(const QString& configFile, Type t, int actions,
-        QWidget *parent, const char *name):
-        KPanelApplet(configFile, t, actions, parent, name), weatherIface(),
-        mFirstRun( false ), mReport( 0 ), mClient( 0 ),
+kweather::kweather(const QString& configFile, K3PanelApplet::Type t, int actions,
+        QWidget *parent) :
+        K3PanelApplet(configFile, t, actions, parent),
+        mFirstRun( false ), mReport( 0 ),
         mContextMenu( 0 ), mWeatherService( 0 ), settingsDialog( 0 ), mTextColor(Qt::black)
 {
-    kdDebug(12004) << "Constructor " << endl;
-    setObjId("weatherIface");
-    
-    setBackgroundOrigin( QWidget::AncestorOrigin );
-    loadPrefs();
-    initContextMenu();
-    initDCOP();
-    
-    dockWidget = new dockwidget(reportLocation, this, "dockwidget");
-    connect(dockWidget, SIGNAL(buttonClicked()), SLOT(doReport()));
-    dockWidget->setViewMode(mViewMode);
-    setLabelColor();
-    
-    timeOut = new QTimer(this, "timeOut" );
-    connect(timeOut, SIGNAL(timeout()), SLOT(timeout()));
-    timeOut->start(10*60*1000);
-    
-    if(mFirstRun)
-        preferences();
-    else
-        timeout();
+        (void) new KweatherAdaptor(this );
+	QDBusConnection::sessionBus().registerObject("/KWeather", this);
+
+	kDebug(12004) << "Constructor ";
+
+	loadPrefs();
+	initContextMenu();
+	initDBUS();
+
+	dockWidget = new dockwidget(reportLocation, this );
+        dockWidget->setObjectName("dockwidget");
+	connect(dockWidget, SIGNAL(buttonClicked()), SLOT(doReport()));
+	dockWidget->setViewMode(mViewMode);
+	dockWidget->setPaletteForegroundColor(mTextColor);
+
+	timeOut = new QTimer(this, "timeOut" );
+	connect(timeOut, SIGNAL(timeout()), SLOT(timeout()));
+	timeOut->start(10*60*1000);
+
+	if(mFirstRun)
+		preferences();
+	else
+		timeout();
 }
 
 kweather::~kweather()
 {
-    delete mWeatherService;
 }
 
 void kweather::initContextMenu()
 {
-    mContextMenu = new KPopupMenu(this);
-    mContextMenu->insertTitle(i18n("KWeather - %1").arg( reportLocation ), -1, 0);
-    mContextMenu->insertItem(SmallIcon("viewmag"), i18n("Show &Report"),
+    mContextMenu = new KMenu(this);
+    mContextMenu->addTitle(i18n("KWeather - %1", reportLocation )/*, -1, 0*/);
+    mContextMenu->insertItem(SmallIcon("zoom-original"), i18n("Show &Report"),
         this, SLOT(doReport()), 0, -1, 1);
-    mContextMenu->insertItem(SmallIcon("reload"), i18n("&Update Now"),
+    mContextMenu->insertItem(SmallIcon("view-refresh"), i18n("&Update Now"),
         this, SLOT(slotUpdateNow()), 0, -1, 2);
     mContextMenu->insertSeparator();
     mContextMenu->insertItem(SmallIcon("kweather"), i18n("&About KWeather"), this, SLOT(about()));
@@ -98,60 +101,50 @@ void kweather::initContextMenu()
     setCustomMenu(mContextMenu);
 }
 
-void kweather::initDCOP()
+void kweather::initDBUS()
 {
-    if ( !mClient )
-        mClient = KApplication::dcopClient();
-    
-    if(!mClient->isAttached())
-        mClient->attach();
-    
-    if(!attach())
-        return;
-    
-    kdDebug(12004) << "attached to the server..." << endl;
-    
-    if ( mWeatherService )
-        delete mWeatherService;
-    
-    mWeatherService = new WeatherService_stub( "KWeatherService", "WeatherService" );
-    
-    if (!connectDCOPSignal(0, 0, "fileUpdate(QString)",
-        "refresh(QString)",false))
-        kdDebug(12004) << "Could not attach dcop signal..." << endl;
-    else
-        kdDebug(12004) << "attached dcop signals..." << endl;
+
+	if(!attach())
+		return;
+
+	kDebug(12004) << "attached to the server...";
+
+	delete mWeatherService;
+	mWeatherService = new OrgKdeKweatherServiceInterface( "org.kde.KWeatherService", "/Service", QDBusConnection::sessionBus() );
+	if(!connect( mWeatherService, SIGNAL(fileUpdate(QString)), this, SLOT(refresh(QString))))
+	   kDebug(12004) << "Could not attach dbus signal...";
 }
 
+
 /** about box */
 void kweather::about(){
-    kdDebug(12004) << "Telling about" << endl;
-    KAboutData aboutData("KWeather", "KWeather", "2.1.0",
-            I18N_NOOP("Weather applet for the Kicker"), KAboutData::License_GPL_V2);
-    aboutData.addAuthor("Ian Reinhart Geiser", "", "geiseri@kde.org",
+    kDebug(12004) << "Telling about";
+    KAboutData aboutData("KWeather", 0, ki18n("KWeather"), "2.1.0",
+            ki18n("Weather applet for the Kicker"), KAboutData::License_GPL_V2);
+    aboutData.addAuthor(ki18n("Ian Reinhart Geiser"), KLocalizedString(), "geiseri@kde.org",
             "http://www.kde.org/");
-    //aboutData.addAuthor("Nadeem Hasan",  "", "nhasan@nadmm.com", "http://www.nadmm.com/");
-    aboutData.addCredit("Nadeem Hasan", I18N_NOOP("Lots of bugfixes,"
+    //aboutData.addAuthor(ki18n("Nadeem Hasan"),  KLocalizedString(), "nhasan@nadmm.com", "http://www.nadmm.com/");
+    aboutData.addCredit(ki18n("Nadeem Hasan"), ki18n("Lots of bugfixes,"
             " improvements and cleanups."), "nhasan@nadmm.com");
-    aboutData.addCredit("Will Andrews", I18N_NOOP("Fixed for BSD port"),
-            "wca@users.sourceforge.net", "");
-    aboutData.addCredit("Ben Burton", I18N_NOOP("Debian fixes"), "benb@acm.org");
-    aboutData.addCredit("Otto Bruggeman", I18N_NOOP("Fixed the i18n stuff and"
+    aboutData.addCredit(ki18n("Will Andrews"), ki18n("Fixed for BSD port"),
+            "wca@users.sourceforge.net");
+    aboutData.addCredit(ki18n("Ben Burton"), ki18n("Debian fixes"), "benb@acm.org");
+    aboutData.addCredit(ki18n("Otto Bruggeman"), ki18n("Fixed the i18n stuff and"
             " made sure the indentation was consistent :P"), "bruggie@home.nl");
-    aboutData.addCredit( "Carles Carbonell Bernado",
-            I18N_NOOP( "Great new weather icons" ), "mail@carlitus.net" );
-    aboutData.addCredit( "John Ratke",
-            I18N_NOOP( "Improvements and more code cleanups" ), "jratke@comcast.net" );
+    aboutData.addCredit( ki18n("Carles Carbonell Bernado"),
+            ki18n( "Great new weather icons" ), "mail@carlitus.net" );
+    aboutData.addCredit( ki18n("John Ratke"),
+            ki18n( "Improvements and more code cleanups" ), "jratke@comcast.net" );
 
-    KAboutApplication about(&aboutData, this, 0);
-    about.setProgramLogo( KGlobal::instance()->iconLoader()->iconPath( "kweather", -KIcon::SizeLarge ) );
+    KAboutApplicationDialog about(&aboutData, this);
+    about.setIcon( KIconLoader::global()->iconPath( "kweather", -KIconLoader::SizeLarge ) );
     about.exec();
 }
 
 /** prefs */
 void kweather::preferences()
 {
-    kdDebug(12004) << "prefs" << endl;
+    kDebug(12004) << "prefs";
 
     savePrefs();
 
@@ -171,7 +164,7 @@ void kweather::preferences()
 /** The help handler */
 void kweather::help()
 {
-    kapp->invokeHelp(QString::null, QString::fromLatin1("kweather"));
+    KToolInvocation::invokeHelp(QString(), QLatin1String("kweather"));
 }
 
 /** Display the current weather report. */
@@ -184,58 +177,54 @@ void kweather::doReport()
         return;
     }
 
-    kdDebug(12004) << "Showing out the report" << endl;
-    if ( mReport == 0 )
-    {
-        mReport = new reportView(reportLocation);
-    
-        connect( mReport, SIGNAL( finished() ), SLOT( slotReportFinished() ) );
-    }
-    
-    mReport->show();
-    mReport->raise();
+	kDebug(12004) << "Showing out the report";
+	if ( mReport == 0 )
+	{
+		mReport = new reportView(reportLocation);
+
+		connect( mReport, SIGNAL( finished() ), SLOT( slotReportFinished() ) );
+	}
+
+	mReport->show();
+	mReport->raise();
 }
 
 void kweather::slotReportFinished(){
-    mReport->delayedDestruct();
-    mReport = 0;
+	mReport->delayedDestruct();
+	mReport = 0;
 }
 
 /** load the application */
 void kweather::loadPrefs(){
-    kdDebug(12004) << "Loading Prefs" << endl;
+    kDebug(12004) << "Loading Prefs";
     KConfig *kcConfig = config();
     kcConfig->reparseConfiguration();
 
     if (!kcConfig->hasGroup ("General Options") )
         mFirstRun = true;
 
-    kcConfig->setGroup("General Options");
-    logOn = kcConfig->readBoolEntry("logging", false);
-    fileName = kcConfig->readPathEntry("log_file_name");
-    reportLocation = kcConfig->readEntry("report_location");
-    mViewMode = kcConfig->readNumEntry("smallview_mode", dockwidget::ShowAll);
-
-    static QColor black(Qt::black);
-    mTextColor = kcConfig->readColorEntry("textColor", &black);
+    KConfigGroup group = kcConfig->group("General Options");
+    logOn = group.readEntry("logging", false);
+    fileName = group.readPathEntry("log_file_name", QString());
+    reportLocation = group.readEntry("report_location");
+    mViewMode = group.readEntry("smallview_mode", int(dockwidget::ShowAll));
+    mTextColor = group.readEntry("textColor", QColor(Qt::black));
 }
 
 /** Save the application mPrefs. */
 void kweather::savePrefs(){
-    kdDebug(12004) << "Saving Prefs..." << endl;
-    KConfig *kcConfig = config();
-    
-    kcConfig->setGroup("General Options");
-    kcConfig->writeEntry("logging", logOn);
-    kcConfig->writeEntry("report_location", reportLocation);
-    kcConfig->writeEntry("smallview_mode", mViewMode);
-    kcConfig->writePathEntry("log_file_name", fileName );
-    kcConfig->sync();
+	kDebug(12004) << "Saving Prefs...";
+	KConfigGroup group = config()->group("General Options");
+	group.writeEntry("logging", logOn);
+	group.writeEntry("report_location", reportLocation);
+	group.writeEntry("smallview_mode", mViewMode);
+	group.writePathEntry("log_file_name", fileName );
+	group.sync();
 }
 
 void kweather::showWeather()
 {
-    kdDebug(12004) << "Show weather" << endl;
+    kDebug(12004) << "Show weather";
     dockWidget->showWeather();
     emit updateLayout();
 }
@@ -245,10 +234,10 @@ void kweather::writeLogEntry()
     // Write data line in the CSV format
     if (logOn && !fileName.isEmpty())
     {
-        kdDebug(12004)<< "Try log file:" << fileName << endl;
+        kDebug(12004)<< "Try log file:" << fileName;
         QFile logFile(fileName);
         QTextStream logFileStream(&logFile);
-        if (logFile.open(IO_Append | IO_ReadWrite))
+        if (logFile.open(QIODevice::Append | QIODevice::ReadWrite))
         {
             QString temperature = mWeatherService->temperature(reportLocation );
             QString wind        = mWeatherService->wind(reportLocation );
@@ -280,46 +269,46 @@ void kweather::writeLogEntry()
 }
 
 /** get new data */
-void kweather::timeout()
-{
-    if ( !mWeatherService )
-        initDCOP();
-    
-    if ( mWeatherService )
-    {
-        // isEmtpy is true for null and 0 length strings
-        if ( !reportLocation.isEmpty() )
-        {
-        kdDebug(12004)<< "Requesting new data for " << reportLocation << endl;
-        mWeatherService->update(reportLocation);
-        }
-    }
+void kweather::timeout(){
+
+	if ( !mWeatherService )
+		initDBUS();
+
+	if ( mWeatherService )
+	{
+		// isEmtpy is true for null and 0 length strings
+		if ( !reportLocation.isEmpty() )
+		{
+			kDebug(12004)<< "Requesting new data for " << reportLocation;
+			mWeatherService->update(reportLocation);
+		}
+	}
 }
 
 int kweather::widthForHeight(int h) const
 {
-    //kdDebug(12004) << "widthForHeight " << h << endl;
-    dockWidget->setOrientation(Horizontal);
-    int w = dockWidget->widthForHeight(h);
-    return w;
+	//kDebug(12004) << "widthForHeight " << h;
+	dockWidget->setOrientation(Qt::Horizontal);
+	int w = dockWidget->widthForHeight(h);
+	return w;
 }
 
 int kweather::heightForWidth(int w) const
 {
-    kdDebug(12004) << "heightForWidth " << w<< endl;
-    dockWidget->setOrientation(Vertical);
-    int h = dockWidget->heightForWidth( w );
-    return h;
+	kDebug(12004) << "heightForWidth " << w;
+	dockWidget->setOrientation(Qt::Vertical);
+	int h = dockWidget->heightForWidth( w );
+	return h;
 }
 
-void kweather::refresh(QString stationID)
+void kweather::refresh(const QString &stationID)
 {
-    kdDebug(12004) << "refresh " << stationID << endl;
-    if( stationID == reportLocation)
-    {
-        showWeather();
-        writeLogEntry();
-    }
+	kDebug(12004) << "refresh " << stationID;
+	if( stationID == reportLocation)
+	{
+		showWeather();
+		writeLogEntry();
+	}
 }
 
 void kweather::slotPrefsAccepted()
@@ -330,14 +319,14 @@ void kweather::slotPrefsAccepted()
 
     dockWidget->setLocationCode(reportLocation);
     dockWidget->setViewMode(mViewMode);
-    setLabelColor();
+    dockWidget->setPaletteForegroundColor(mTextColor);
     emit updateLayout();
 
     if (logOn && !fileName.isEmpty())
     {
         QFile logFile(fileName);
         // Open the file, create it if not already exists
-        if (logFile.open(IO_ReadWrite))
+        if (logFile.open(QIODevice::ReadWrite))
         {
             if (logFile.size() == 0)
             {
@@ -349,7 +338,7 @@ void kweather::slotPrefsAccepted()
         }
         else
         {
-            kdDebug(12004) << "There was an error opening the file...." << endl;
+            kDebug(12004) << "There was an error opening the file....";
             KMessageBox::sorry( this,
                     i18n("For some reason a new log file could not be opened.\n"
                     "Please check to see if your disk is full or if you have "
@@ -363,9 +352,9 @@ void kweather::slotPrefsAccepted()
 
 void kweather::mousePressEvent(QMouseEvent *e)
 {
-    if ( e->button() != RightButton )
+    if ( e->button() != Qt::RightButton )
     {
-        KPanelApplet::mousePressEvent( e );
+        K3PanelApplet::mousePressEvent( e );
         return;
     }
 
@@ -374,33 +363,30 @@ void kweather::mousePressEvent(QMouseEvent *e)
 
 void kweather::slotUpdateNow()
 {
-    if ( !mWeatherService )
-         initDCOP();
-
     mWeatherService->forceUpdate(reportLocation );
 }
 
 bool kweather::attach()
 {
     QString error;
-    kdDebug(12004) << "Looking for dcop service..." << endl;
-    if (!mClient->isApplicationRegistered("KWeatherService"))
+    kDebug(12004) << "Looking for dbus service...";
+    if(!QDBusConnection::sessionBus().interface()->isServiceRegistered("org.kde.KWeatherService"))
     {
-        kdDebug(12004) << "Could not find service so I am starting it..."
+        kDebug(12004) << "Could not find service so I am starting it..."
             << endl;
-        if (!KApplication::startServiceByDesktopName("kweatherservice",
+        if (!KToolInvocation::startServiceByDesktopName("kweatherservice",
             QStringList(), &error))
         {
-            kdDebug(12004) << "Starting KWeatherService failed with message: "
+            kDebug(12004) << "Starting KWeatherService failed with message: "
                 << error << endl;
             return false;
         }
 
-        kdDebug (12004) << "Service Started..." << endl;
+        kDebug (12004) << "Service Started...";
     }
     else
     {
-        kdDebug(12004) << "Found weather service..." << endl;
+        kDebug(12004) << "Found weather service...";
     }
 
     return true;
@@ -408,18 +394,8 @@ bool kweather::attach()
 
 void kweather::resizeEvent(QResizeEvent *e)
 {
-    kdDebug(12004) << "KWeather Resize event " << e->size() << endl;
-    dockWidget->resizeView(e->size());
-}
-
-void kweather::setLabelColor()
-{
-    setPaletteForegroundColor(mTextColor);
-}
-
-void kweather::paletteChange(const QPalette &)
-{
-    setLabelColor();
+	kDebug(12004) << "KWeather Resize event " << e->size();
+	dockWidget->resizeView(e->size());
 }
 
 #include "kweather.moc"
